==> monodevelop_2.0+dfsg.orig.tar.gz: monodevelop-2.0/src/core/MonoDevelop.Projects/MonoDevelop.Projects/FileFormat.cs <==
// FileFormat.cs
//
// Author:
//   Lluis Sanchez Gual <lluis@novell.com>
//
// Copyright (c) 2008 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//
//

using System;
using System.Collections.Generic;
using MonoDevelop.Projects.Extensions;

namespace MonoDevelop.Projects
{
	public class FileFormat
	{
		string id;
		string name;
		IFileFormat format;
		
		public string Id {
			get {
				return id;
			}
		}

		public string Name {
			get {
				return name;
			}
		}
		
		public string GetValidFileName (object obj, string fileName)
		{
			return format.GetValidFormatName (obj, fileName);
		}
		
		public IEnumerable<string> GetCompatibilityWarnings (object obj)
		{
			IEnumerable<string> res = format.GetCompatibilityWarnings (obj);
			return res ?? new string [0];
		}
		
		internal IFileFormat Format {
			get { return format; }
		}
		
		internal FileFormat (IFileFormat format, string id, string name)
		{
			this.id = id;
			this.name = name ?? id;
			this.format = format;
		}
	}
}

==> monodevelop_2.2.1+dfsg.orig.tar.gz: monodevelop-2.2.1/src/core/MonoDevelop.Projects/MonoDevelop.Projects/FileFormat.cs <==
// FileFormat.cs
//
// Author:
//   Lluis Sanchez Gual <lluis@novell.com>
//
// Copyright (c) 2008 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//
//

using System;
using System.Collections.Generic;
using MonoDevelop.Projects.Extensions;

namespace MonoDevelop.Projects
{
	public class FileFormat
	{
		string id;
		string name;
		IFileFormat format;
		
		public string Id {
			get {
				return id;
			}
		}

		public string Name {
			get {
				return name;
			}
		}
		
		public string GetValidFileName (object obj, string fileName)
		{
			return format.GetValidFormatName (obj, fileName);
		}
		
		public IEnumerable<string> GetCompatibilityWarnings (object obj)
		{
			IEnumerable<string> res = format.GetCompatibilityWarnings (obj);
			return res ?? new string [0];
		}
		
		public bool CanWrite (object obj)
		{
			return format.CanWriteFile (obj);
		}
		
		public bool SupportsMixedFormats {
			get { return format.SupportsMixedFormats; }
		}
		
		internal IFileFormat Format {
			get { return format; }
		}
		
		internal FileFormat (IFileFormat format, string id, string name)
		{
			this.id = id;
			this.name = name ?? id;
			this.format = format;
		}
	}
}
